@@ -23,6 +23,13 @@ impl ListView {
         }
     }
     #[inline]
+    pub fn children_mut(&mut self) -> &Vec<ListItem> {
+        match self {
+            Self::Ordered(v) => &mut v.children,
+            Self::Orderless(v) => &mut v.children,
+        }
+    }
+    #[inline]
     pub fn first_prefix(&self) -> Option<&ListPrefixSymbol> {
         self.children().first().map(|f| &f.prefix.value)
     }
